﻿/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
**/
using System.Windows;
using System.Data;
using System;
using jp.co.ftf.jobcontroller.Common;
using jp.co.ftf.jobcontroller.DAO;
using System.Windows.Controls;
//*******************************************************************
//                                                                  *
//                                                                  *
//  Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.       *
//                                                                  *
//  * @author DHC 劉 旭 2012/11/05 新規作成<BR>                      *
//                                                                  *
//                                                                  *
//*******************************************************************
namespace jp.co.ftf.jobcontroller.JobController.Form.JobEdit
{
    /// <summary>
    /// TaskSetting.xaml の相互作用ロジック
    /// </summary>
    public partial class TaskSetting : Window
    {
        #region コンストラクタ
        public TaskSetting(IRoom room, string jobId)
        {
            InitializeComponent();

            _myJob = room;

            _oldJobId = jobId;

            SetValues(jobId);
        }
        #endregion

        #region プロパティ
        /// <summary>ジョブ</summary>
        private IRoom _myJob;
        public IRoom MyJob
        {
            get
            {
                return _myJob;
            }
            set
            {
                _myJob = value;
            }
        }

        /// <summary>ジョブID</summary>
        private string _oldJobId;
        public string OldJobId
        {
            get
            {
                return _oldJobId;
            }
            set
            {
                _oldJobId = value;
            }
        }

        /// <summary>ジョブネット管理テーブル</summary>
        private DataTable _jobNetTable;
        public DataTable JobNetTable
        {
            get
            {
                return _jobNetTable;
            }
            set
            {
                _jobNetTable = value;
            }
        }
        #endregion

        #region イベント
        /// <summary> 登録処理</summary>
        /// <param name="sender">源</param>
        /// <param name="e">イベント</param>
        private void btnToroku_Click(object sender, RoutedEventArgs e)
        {
            // 入力チェック 
            if (!InputCheck())
            {
                return;
            }

            // 入力されたジョブID 
            string newJobId = txtJobId.Text;
            // 入力されたジョブ名 
            string newJobNm = txtJobName.Text;

            // ジョブ管理テーブルの更新 
            DataRow[] drJobCon = _myJob.Container.JobControlTable.Select("job_id='" + OldJobId + "'");
            if (drJobCon != null && drJobCon.Length > 0)
            {
                drJobCon[0]["job_id"] = newJobId;
                drJobCon[0]["job_name"] = newJobNm;
            }

            // タスクアイコン設定テーブルの更新 
            DataRow[] drTask = _myJob.Container.IconTaskTable.Select("job_id='" + OldJobId + "'");
            if (drTask != null && drTask.Length > 0)
            {
                drTask[0]["job_id"] = newJobId;
                drTask[0]["submit_jobnet_id"] = Convert.ToString(combJobNetId.SelectedValue);
            }

            // ジョブIDが変更された場合、フロー管理テーブルを更新 
            if (!_oldJobId.Equals(newJobId))
                CommonUtil.UpdateFlowForJobId(_myJob.Container.FlowControlTable, _oldJobId, newJobId);

            // 画面再表示 
            _myJob.JobId = newJobId;
            _myJob.JobName = newJobNm;
            _myJob.Container.SetedJobIds[_myJob.JobId]="1";
            this.Close();
        }

        /// <summary>ジョブネットIDを変える</summary>
        /// <param name="sender">源</param>
        /// <param name="e">イベント</param>
        private void combJobNetId_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            string jobNetId = Convert.ToString(combJobNetId.SelectedValue);
            DataRow[] rowJobNet = this.JobNetTable.Select("jobnet_id='" + jobNetId + "'");
            if (rowJobNet != null && rowJobNet.Length > 0)
            {
                tbJobNetName.Text = Convert.ToString(rowJobNet[0]["jobnet_name"]);
            }
        }

        /// <summary>キャンセルをクリック</summary>
        /// <param name="sender">源</param>
        /// <param name="e">イベント</param>
        private void btnCancel_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        //*******************************************************************
        /// <summary>画面を閉める</summary>
        /// <param name="sender">源</param>
        /// <param name="e">イベント</param>
        //*******************************************************************
        private void Window_Closed(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if (_myJob.ItemEditType == Consts.EditType.READ)
                _myJob.ResetInitColor();
        }
        #endregion

        #region publicメッソド
        public void SetDisable()
        {
            txtJobId.IsEnabled = false;
            txtJobName.IsEnabled = false;
            btnToroku.IsEnabled = false;
            combJobNetId.IsEnabled = false;

        }
        #endregion

        #region privateメッソド

        /// <summary> 値のセットと表示処理</summary>
        /// <param name="sender">源</param>
        private void SetValues(string jobId)
        {
            // ジョブ管理テーブルのデータを取得 
            DataRow[] rowJob = _myJob.Container.JobControlTable.Select("job_id='" + jobId + "'");
            if (rowJob != null && rowJob.Length > 0)
            {
                txtJobId.Text = jobId;
                txtJobName.Text = Convert.ToString(rowJob[0]["job_name"]);
            }

            // DB接続をオープン 
            DBConnect dbAccess = new DBConnect(LoginSetting.ConnectStr);
            dbAccess.CreateSqlConnect();
            // ジョブネット管理テーブルのデータを取得 
            JobnetControlDAO _jobnetControlDAO = new JobnetControlDAO(dbAccess);
            if (LoginSetting.Authority == Consts.AuthorityEnum.SUPER)
            {
                this.JobNetTable = _jobnetControlDAO.GetInfoByUserIdSuper();
            }
            else
            {
                this.JobNetTable = _jobnetControlDAO.GetInfoByUserId(LoginSetting.UserID);
            }
            // DB接続をクローズ 
            dbAccess.CloseSqlConnect();
            combJobNetId.ItemsSource = JobNetTable.DefaultView;
            combJobNetId.DisplayMemberPath = Convert.ToString(JobNetTable.Columns["jobnet_id"]);
            combJobNetId.SelectedValuePath = Convert.ToString(JobNetTable.Columns["jobnet_id"]);

            // タスクアイコン設定テーブルのデータを取得 
            DataRow[] rowTask;
            if (_myJob.ContentItem.InnerJobId == null)
            {
                rowTask = _myJob.Container.IconTaskTable.Select("job_id='" + jobId + "'");
            }
            else
            {
                rowTask = _myJob.Container.IconTaskTable.Select("inner_job_id=" + _myJob.ContentItem.InnerJobId);
            }
            if (rowTask != null && rowTask.Length > 0)
            {
                string jobNetId = Convert.ToString(rowTask[0]["submit_jobnet_id"]);
                combJobNetId.SelectedValue = jobNetId;

                DataRow[] rowJobNet = this.JobNetTable.Select("jobnet_id='" + jobNetId + "'");
                if (rowJobNet != null && rowJobNet.Length > 0)
                {
                    tbJobNetName.Text = Convert.ToString(rowJobNet[0]["jobnet_name"]);
                }
            }
        }

        /// <summary> 各項目のチェック処理</summary>
        private bool InputCheck()
        {
            // ジョブID 
            string jobIdForChange = "ジョブID";
            String jobId = txtJobId.Text;
            // 未入力の場合 
            if (CheckUtil.IsNullOrEmpty(jobId))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_COMMON_001,
                    new string[] { jobIdForChange });
                return false;
            }
            // 桁数チェック 
            if (CheckUtil.IsLenOver(jobId, 32))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_COMMON_003,
                    new string[] { jobIdForChange, "32" });
                return false;
            }
            // 半角英数字とハイフン（-）チェック 
            if (!CheckUtil.IsHankakuStrAndHyphen(jobId))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_COMMON_005,
                    new string[] { jobIdForChange });
                return false;
            }
            // 予約語（START）チェック 
            if (CheckUtil.IsHoldStrSTART(jobId))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_JOBEDIT_001);
                return false;
            }
            // すでに登録済みの場合 
            DataRow[] rowJob = _myJob.Container.JobControlTable.Select("job_id='" + jobId + "'");
            if (rowJob != null && rowJob.Length > 0)
            {
                foreach (DataRow row in rowJob)
                {
                    if (!jobId.Equals(_oldJobId) && jobId.Equals(row["job_id"]))
                    {
                        CommonDialog.ShowErrorDialog(Consts.ERROR_COMMON_004,
                            new string[] { jobIdForChange });
                        return false;
                    }
                }
            }

            // ジョブ名 
            string jobNameForChange = "ジョブ名";
            String jobName = txtJobName.Text;
            // バイト数チェック 
            if (CheckUtil.IsLenOver(jobName, 64))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_COMMON_003,
                    new string[] { jobNameForChange, "64" });
                return false;
            }

            // ジョブネットID 
            string jobNetIdForChange = "ジョブネットID";
            string jobNetIdOtherForChange = "他ジョブネットID";
            String jobNetId = Convert.ToString(combJobNetId.SelectedValue);
            // 未入力の場合 
            if (CheckUtil.IsNullOrEmpty(jobNetId))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_COMMON_001,
                    new string[] { jobNetIdForChange });
                return false;
            }
            // 自ジョブネットIDチェック 
            if (_myJob.Container.JobnetId.Equals(jobNetId))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_COMMON_001,
                    new string[] { jobNetIdOtherForChange });
                return false;
            }
            // ジョブネットIDの存在チェック 
            DBConnect dbAccess = new DBConnect(LoginSetting.ConnectStr);
            dbAccess.CreateSqlConnect();
            JobnetControlDAO _jobnetControlDAO = new JobnetControlDAO(dbAccess);
            string count = _jobnetControlDAO.GetCountByJobNetId(jobNetId);
            dbAccess.CloseSqlConnect();
            if ("0".Equals(count))
            {
                CommonDialog.ShowErrorDialog(Consts.ERROR_JOBEDIT_002);
                return false;
            }

            return true;
        }
        #endregion
    }
}
