/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

/*
** $Date:: 2012-11-26 13:15:38 +0900 #$
** $Revision: 2725 $
** $Author: ossinfra@FITECHLABS.CO.JP $
**/

#include "common.h"
#include "log.h"

/******************************************************************************
 *                                                                            *
 * Function: check_timeout                                                    *
 *                                                                            *
 * Purpose: check whether the timeout has occurred                            *
 *                                                                            *
 * Parameters: timeout (in) - timeout period (minute)                         *
 *             start_time (in) - job icon start time (YYYYMMDDHHMMSS)         *
 *                                                                            *
 * Return value:  SUCCEED - timeout occurs                                    *
 *                FAIL - no timeout                                           *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
int check_timeout(char *timeout, char *start_time)
{
    struct tm *tm, stm;
    time_t now;
    int i_year, i_mon, i_day, i_hour, i_min, i_timeout, rc;
    char year[5], mon[3], day[3], hour[3], min[3];
    char *now_time, *edit_time;
    const char *__function_name = "check_timeout";

    if (timeout == NULL || start_time == NULL)
        return FAIL;

    zabbix_log(LOG_LEVEL_DEBUG, "In %s() timeout: %s, start_time: %s",
               __function_name, timeout, start_time);

    i_timeout = atoi(timeout);
    if (i_timeout == 0)
        return FAIL;

    time(&now);
    tm = localtime(&now);

    now_time = zbx_dsprintf(NULL, "%04d%02d%02d%02d%02d",
                            (tm->tm_year + 1900),
                            (tm->tm_mon + 1),
                            tm->tm_mday, tm->tm_hour, tm->tm_min);


    zbx_strlcpy(year, start_time, 5);
    year[4] = '\0';
    zbx_strlcpy(mon, (start_time + 4), 3);
    mon[2] = '\0';
    zbx_strlcpy(day, (start_time + 6), 3);
    day[2] = '\0';
    zbx_strlcpy(hour, (start_time + 8), 3);
    hour[2] = '\0';
    zbx_strlcpy(min, (start_time + 10), 3);
    min[2] = '\0';

    i_year = atoi(year);
    i_mon = atoi(mon);
    i_day = atoi(day);
    i_hour = atoi(hour);
    i_min = atoi(min);

    stm.tm_year = i_year - 1900;
    stm.tm_mon = i_mon - 1;
    stm.tm_mday = i_day;
    stm.tm_hour = i_hour;
    stm.tm_min = i_min + i_timeout;
    stm.tm_sec = 0;
    stm.tm_isdst = -1;

    mktime(&stm);

    edit_time = zbx_dsprintf(NULL, "%04d%02d%02d%02d%02d",
                             (stm.tm_year + 1900),
                             (stm.tm_mon + 1),
                             stm.tm_mday, stm.tm_hour, stm.tm_min);

    /* timeout chack */
    if (strcmp(edit_time, now_time) <= 0) {
        rc = SUCCEED;
    } else {
        rc = FAIL;
    }

    zbx_free(now_time);
    zbx_free(edit_time);

    return rc;
}
