/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

/*
** $Date:: 2012-11-29 13:09:55 +0900 #$
** $Revision: 2833 $
** $Author: ossinfra@FITECHLABS.CO.JP $
**/

#include "common.h"
#include "comms.h"
#include "log.h"

#if defined(ZABBIX_SERVICE)
#include "service.h"
#elif defined(ZABBIX_DAEMON)
#include "daemon.h"
#endif

#include "jacommon.h"
#include "jajobobject.h"
#include "jatcp.h"
#include "jatelegram.h"
#include "jaagent.h"
#include "listener.h"

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
static void process_listener(zbx_sock_t * sock)
{
    char *buf;
    char response[JA_MAX_TELEGRAM_LEN];
    ja_job_object job;

    ja_job_object_init(&job);
    if (SUCCEED == zbx_tcp_recv_to(sock, &buf, CONFIG_TIMEOUT)) {
        zbx_rtrim(buf, "\r\n");
        if (ja_telegram_from_jobrun(buf, &job) == FAIL)
            goto sender;
        if (ja_agent_begin(&job) == FAIL)
            goto sender;
        job.result = JA_JOBRUN_RES_SUCCEED;
    } else {
        zabbix_log(LOG_LEVEL_WARNING, "Process listener error: %s",
                   zbx_tcp_strerror());
        return;
    }

  sender:
    if (ja_telegram_to_jobrun_res(&job, response) == FAIL)
        return;
    if (zbx_tcp_send_to(sock, response, CONFIG_TIMEOUT) == FAIL) {
        zabbix_log(LOG_LEVEL_WARNING, "TCP send to error: %s",
                   zbx_tcp_strerror());
    }
    return;
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
ZBX_THREAD_ENTRY(listener_thread, args)
{
    int ret, local_request_failed = 0;
    zbx_sock_t sock;

    assert(args);
    assert(((zbx_thread_args_t *) args)->args);

    zabbix_log(LOG_LEVEL_INFORMATION,
               "jobarg_agentd #%d started [listener]",
               ((zbx_thread_args_t *) args)->thread_num);

    memcpy(&sock, (zbx_sock_t *) ((zbx_thread_args_t *) args)->args,
           sizeof(zbx_sock_t));
    zbx_free(args);

    while (ZBX_IS_RUNNING()) {
        zbx_setproctitle("listener [waiting for connection]");
        if (SUCCEED == (ret = ja_tcp_accept(&sock))) {
            local_request_failed = 0;
            zbx_setproctitle("listener [processing request]");
            if (SUCCEED ==
                (ret =
                 zbx_tcp_check_security(&sock, CONFIG_HOSTS_ALLOWED, 0)))
                process_listener(&sock);
            zbx_tcp_unaccept(&sock);
        }

        if (SUCCEED == ret)
            continue;

        zabbix_log(LOG_LEVEL_WARNING, "Listener error");

        if (local_request_failed++ > 1000) {
            zabbix_log(LOG_LEVEL_WARNING,
                       "Too many consecutive errors on accept() call.");
            local_request_failed = 0;
        }
        if (ZBX_IS_RUNNING())
            zbx_sleep(1);
    }

    zabbix_log(LOG_LEVEL_INFORMATION, "jobarg_agentd listener stopped");
    ZBX_DO_EXIT();
    zbx_thread_exit(0);
}
